@@ -3,7 +3,6 @@ import sys
 import time
 
 from collections import deque
-from json import dumps
 from pathlib import Path
 from pprint import pformat
 from signal import signal, Signals, SIGTERM, SIGUSR1, SIGTSTP, SIGCONT
@@ -19,6 +18,7 @@ from py3status.helpers import print_stderr
 from py3status.i3status import I3status
 from py3status.parse_config import process_config
 from py3status.module import Module
+from py3status.output import OutputFormat
 from py3status.profiling import profile
 from py3status.udev_monitor import UdevMonitor
 
@@ -251,12 +251,11 @@ class Py3statusWrapper:
         """
         self.config = vars(options)
         self.i3bar_running = True
-        self.last_loop_ts = time.monotonic()
+        self.inhibit_signal_ts = time.monotonic()
         self.last_refresh_ts = time.monotonic()
-        self.last_sigcont_ts = None
-        self.last_sigtstp_ts = None
         self.lock = Event()
         self.modules = {}
+        self.next_allowed_signal = SIGTSTP
         self.notified_messages = set()
         self.options = options
         self.output_modules = {}
@@ -614,6 +613,16 @@ class Py3statusWrapper:
         self.log("config file: {}".format(self.config["i3status_config_path"]))
         self.config["py3_config"] = process_config(config_path, self)
 
+        # autodetect output_format
+        output_format = self.config["py3_config"]["general"]["output_format"]
+        if output_format is None:
+            if sys.stdout.isatty():
+                print("py3status: trying to auto-detect output_format setting")
+                print('py3status: auto-detected "term"')
+                output_format = "term"
+
+        self.config["py3_config"]["general"]["output_format"] = output_format or "i3bar"
+
         # read resources
         if "resources" in str(self.config["py3_config"].values()):
             from subprocess import check_output
@@ -723,6 +732,20 @@ class Py3statusWrapper:
             # load and spawn i3status.conf configured modules threads
             self.load_modules(self.py3_modules, user_modules)
 
+        # determine the target output format
+        self.output_format = OutputFormat.instance_for(
+            self.config["py3_config"]["general"]["output_format"]
+        )
+
+        # determine the output separator, if needed
+        color_separator = None
+        if self.config["py3_config"]["general"]["colors"]:
+            color_separator = self.config["py3_config"]["general"]["color_separator"]
+        self.output_format.format_separator(
+            self.config["py3_config"]["general"].get("separator", None),
+            color_separator,
+        )
+
     def notify_user(
         self,
         msg,
@@ -1016,31 +1039,36 @@ class Py3statusWrapper:
                     # Color: substitute the config defined color
                     if "color" not in output:
                         output["color"] = color
-        # Create the json string output.
-        return ",".join(dumps(x) for x in outputs)
+        # format output and return
+        return self.output_format.format(outputs)
 
     def i3bar_stop(self, signum, frame):
         if (
-            self.last_sigcont_ts
-            and self.last_sigtstp_ts
-            and self.last_sigcont_ts > self.last_sigtstp_ts
-            and time.monotonic() - self.last_loop_ts < 1
+            self.next_allowed_signal == signum
+            and time.monotonic() > self.inhibit_signal_ts
         ):
             self.log(f"received stop_signal {Signals(signum).name}")
             self.i3bar_running = False
             # i3status should be stopped
             self.i3status_thread.suspend_i3status()
             self.sleep_modules()
+            self.next_allowed_signal = SIGCONT
         else:
             self.log(f"inhibited stop_signal {Signals(signum).name}", level="warning")
-        self.last_sigtstp_ts = time.monotonic()
+            self.inhibit_signal_ts = time.monotonic() + 0.1
 
     def i3bar_start(self, signum, frame):
-        self.log(f"received resume signal {Signals(signum).name}")
-        self.last_loop_ts = time.monotonic()
-        self.last_sigcont_ts = time.monotonic()
-        self.i3bar_running = True
-        self.wake_modules()
+        if (
+            self.next_allowed_signal == signum
+            and time.monotonic() > self.inhibit_signal_ts
+        ):
+            self.log(f"received resume signal {Signals(signum).name}")
+            self.i3bar_running = True
+            self.wake_modules()
+            self.next_allowed_signal = self.stop_signal
+        else:
+            self.log(f"inhibited start_signal {Signals(signum).name}", level="warning")
+            self.inhibit_signal_ts = time.monotonic() + 0.1
 
     def sleep_modules(self):
         # Put all py3modules to sleep so they stop updating
@@ -1085,17 +1113,13 @@ class Py3statusWrapper:
         # items in the bar
         output = [None] * len(py3_config["order"])
 
-        write = sys.__stdout__.write
-        flush = sys.__stdout__.flush
-
         # start our output
         header = {
             "version": 1,
             "click_events": self.config["click_events"],
             "stop_signal": self.stop_signal or 0,
         }
-        write(dumps(header))
-        write("\n[[]\n")
+        self.output_format.write_header(header)
 
         update_due = None
         # main loop
@@ -1111,8 +1135,6 @@ class Py3statusWrapper:
             while not self.i3bar_running:
                 time.sleep(0.1)
 
-            self.last_loop_ts = time.monotonic()
-
             # check if an update is needed
             if self.update_queue:
                 while len(self.update_queue):
@@ -1124,8 +1146,5 @@ class Py3statusWrapper:
                         # store the output as json
                         output[index] = out
 
-                # build output string
-                out = ",".join(x for x in output if x)
-                # dump the line to stdout
-                write(f",[{out}]\n")
-                flush()
+                # build output string and dump to stdout
+                self.output_format.write_line(output)
