@@ -17,6 +17,7 @@ Requires:
     trizen: lightweight pacman wrapper and AUR helper
     yay: yet another yogurt. pacman wrapper and aur helper written in go
     paru: feature packed AUR helper
+    pikaur: pacman wrapper and AUR helper written in python
 
 @author Iain Tatch <iain.tatch@gmail.com>
 @license BSD
@@ -32,8 +33,7 @@ STRING_NOT_INSTALLED = "{} not installed"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 600
@@ -47,7 +47,7 @@ class Py3status:
         helper = {
             "pacman": self.py3.check_commands(["checkupdates"]),
             "aur": self.py3.check_commands(
-                ["auracle", "trizen", "yay", "cower", "paru"]
+                ["auracle", "trizen", "yay", "paru", "pikaur"]
             ),
         }
         if self.format:
@@ -89,13 +89,6 @@ class Py3status:
         except self.py3.CommandError as ce:
             return None if ce.error else 0
 
-    def _get_cower_updates(self):
-        try:
-            self.py3.command_output(["cower", "-u"])
-            return None
-        except self.py3.CommandError as ce:
-            return len(ce.output.splitlines())
-
     def _get_trizen_updates(self):
         try:
             updates = self.py3.command_output(["trizen", "-Suaq"])
@@ -114,8 +107,15 @@ class Py3status:
         try:
             updates = self.py3.command_output(["paru", "-Qua"])
             return len(updates.splitlines())
-        except self.py3.CommandError:
-            return None
+        except self.py3.CommandError as ce:
+            return None if ce.error else 0
+
+    def _get_pikaur_updates(self):
+        try:
+            updates = self.py3.command_output(["pikaur", "-Qua"])
+            return len(updates.splitlines())
+        except self.py3.CommandError as ce:
+            return None if ce.error else 0
 
     def arch_updates(self):
         pacman, aur, total, full_text = None, None, None, ""
