@@ -26,10 +26,6 @@ Configuration parameters:
         (default False)
     max_volume: Allow the volume to be increased past 100% if available.
         pactl and pamixer supports this. (default 120)
-    start_delay: Number of seconds to wait before starting this module.
-        This allows some systems to start the audio backend before we
-        try picking it up.
-        (default 0)
     thresholds: Threshold for percent volume.
         (default [(0, 'bad'), (20, 'degraded'), (50, 'good')])
     volume_delta: Percentage amount that the volume is increased or
@@ -118,10 +114,13 @@ class Amixer(Audio):
     def setup(self, parent):
         if self.card is None:
             self.card = "0"
-        if self.channel is None:
-            self.channel = "Capture" if self.is_input else "Master"
         if self.device is None:
             self.device = "default"
+        if self.channel is None:
+            controls = self.parent.py3.command_output(
+                ["amixer", "-c", self.card, "-D", self.device, "scontrols"]
+            ).splitlines()
+            self.channel = controls[-abs(int(self.is_input))].split("'")[1::2][0]
         self.cmd = [
             "amixer",
             "-M",
@@ -232,7 +231,7 @@ class Pactl(Audio):
         device_id = None
 
         # Find the default device for the device type
-        default_dev_pattern = re.compile(fr"^Default {self.device_type_cap}: (.*)$")
+        default_dev_pattern = re.compile(rf"^Default {self.device_type_cap}: (.*)$")
         output = self.command_output(["pactl", "info"])
         for info_line in output.splitlines():
             default_dev_match = default_dev_pattern.match(info_line)
@@ -329,7 +328,6 @@ class Py3status:
     format_muted = r"[\?if=is_input 😶|♪]: muted"
     is_input = False
     max_volume = 120
-    start_delay = 0
     thresholds = [(0, "bad"), (20, "degraded"), (50, "good")]
     volume_delta = 5
 
@@ -355,12 +353,14 @@ class Py3status:
                     "param": "threshold_degraded",
                     "msg": "obsolete set using thresholds parameter",
                 },
+                {
+                    "param": "start_delay",
+                    "msg": "obsolete parameter",
+                },
             ],
         }
 
     def post_config_hook(self):
-        if self.start_delay:
-            sleep(int(self.start_delay))
         if not self.command:
             commands = ["pamixer", "pactl", "amixer"]
             # pamixer, pactl requires pulseaudio to work
@@ -380,9 +380,21 @@ class Py3status:
         if self.device is not None:
             self.device = str(self.device)
 
-        self.backend = globals()[self.command.capitalize()](self)
+        self._init_backend()
         self.color_muted = self.py3.COLOR_MUTED or self.py3.COLOR_BAD
 
+    def _init_backend(self):
+        # attempt it a few times since the audio service may still be loading during startup
+        for i in range(6):
+            try:
+                self.backend = globals()[self.command.capitalize()](self)
+                return
+            except Exception:  # noqa e722
+                # try again later (exponential backoff)
+                sleep(0.5 * 2**i)
+
+        self.backend = globals()[self.command.capitalize()](self)
+
     def volume_status(self):
         perc, muted = self.backend.get_volume()
         color = None
